<?php

/***************************************************************************
 *   Copyright (C) 2006 by Kevin McBride                                   *
 *   kevin@planetsaphire.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

include "phptempl/error.php";
include "phptempl/headfoot.php";
include "db/mysql.php";
include "phptempl/epl_temp.php";


/*
retrievesid()

Retrieves a SID.  Returns a SID.
*/

function retrievesid($sdb)
{
	/* If SID was not given, there's nothing for us to do. */
	if ( is_null($_GET["sid"]) )
	{
		loginerror();
	}

	/* Check the existing SID and create a new SID. */
	$theSID = $sdb->verifySID($_GET["sid"], $_SERVER["REMOTE_ADDR"]);
	if ( $theSID == false )
	{
		loginerror();
	}

	/* Return the new SID. */
	return $theSID;
}


/*
loginuser()

Logs in a user.  Returns a SID.
*/

function loginuser($sdb)
{
	/* Get the employee ID. */
	$actualempid = intval($_POST["empid"]);

	/* Check to see if it is subtractable. */
	if ( $actualempid < 1001 )
	{
		/* EmpID is invalid; tell caller we can't process this transaction. */
		loginerror();
	}

	/* Make the actual employee ID. */
	$actualempid = $actualempid - 1000;

	/* Call the login function. */
	$theSID = $sdb->loginEmp($actualempid, $_POST["emppasswd"], 
		$_SERVER["REMOTE_ADDR"]);
	/* Check for error. */
	if ( $theSID == false )
	{
		loginerror();
	}

	return $theSID;
}


/*
main()

Main of script starts here
*/

/* Create a new SaphireDB object. */
$sdb = new SaphireDB();

/* Check to see if we have an employee ID. */
if ( is_null($_POST["empid"]) | is_null($_POST["emppasswd"]) )
{
	/* It's NULL; attempt to retrieve the SID. */
	$theSID = retrievesid($sdb);
} else {
	/* Log in the user. */
	$theSID = loginuser($sdb);
}

/* Check for SID errors. */
if ( $theSID == false )
{
	loginerror();
}

/* Get the employee ID. */
$theEmpID = $sdb->getEmpID();
if ( $theEmpID == false )
{
	loginerror();
}

/* Get the full name. */
$theEmpName = $sdb->getEmpFullName();
if ( $theEmpName == NULL )
{
	loginerror();
}

/* Get the privilege info. */
$theEmpPrivs = $sdb->getPrivilegeInfo();
if ( $theEmpPrivs == WWWBIZ_EMPPRIVS_NONE )
{
	loginerror();
}

/* Output the visible text (template). */
epl_output($theSID, $theEmpID, $theEmpName, $theEmpPrivs);


?>

